@@ -17,10 +17,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
-
-#include <gconf/gconf-backend.h>
-#include <gconf/gconf-internals.h>
-#include <gconf/gconf.h>
+#include "config.h"
+#include "gconf/gconf-backend.h"
+#include "gconf/gconf-internals.h"
+#include "gconf/gconf.h"
 
 #include <stdio.h>
 #include <time.h>
@@ -59,7 +59,6 @@ typedef struct
 {
   GConfSource source; /* inherit from GConfSource */
   char *root_dir;
-  guint timeout_id;
   GConfLock* lock;
   MarkupTree *tree;
   guint dir_mode;
@@ -875,21 +874,6 @@ gconf_backend_get_vtable (void)
  *  MarkupSource
  */ 
 
-/* This timeout periodically unloads
- * data that hasn't been used in a while.
- */
-static gboolean
-cleanup_timeout (gpointer data)
-{
-#if 0
-  MarkupSource* ms = (MarkupSource*)data;
-
-  cache_clean(ms->cache, 60*5 /* 5 minutes */);
-#endif
-  
-  return TRUE;
-}
-
 static MarkupSource*
 ms_new (const char* root_dir,
         guint       dir_mode,
@@ -903,10 +887,6 @@ ms_new (const char* root_dir,
 
   ms = g_new0(MarkupSource, 1);
 
-  ms->timeout_id = g_timeout_add (1000*60*5, /* 1 sec * 60 s/min * 5 min */
-                                  cleanup_timeout,
-                                  ms);
-
   ms->root_dir = g_strdup (root_dir);
   
   ms->lock = lock;
@@ -941,12 +921,6 @@ ms_destroy (MarkupSource* ms)
       error = NULL;
     }
   
-  if (!g_source_remove (ms->timeout_id))
-    {
-      /* should not happen, don't translate */
-      gconf_log (GCL_ERR, "timeout not found to remove?");
-    }
-
   markup_tree_unref (ms->tree);
 
   g_free (ms->root_dir);
